@@ -85,7 +85,7 @@ class TestSemanticTypes(SampleClassifierTestPluginBase):
                         name='outlier', index=exp_index)
         obs = transformer(exp)
         obs = pd.read_csv(str(obs), sep='\t', header=0, index_col=0,
-                          squeeze=True)
+                          ).squeeze('columns')
         self.assertEqual(sorted(exp), sorted(obs))
 
     def test_boolean_format_to_pd_series(self):
@@ -152,7 +152,7 @@ class TestSemanticTypes(SampleClassifierTestPluginBase):
                         name='prediction', index=['a', 'b', 'c', 'd'])
         obs = transformer(exp)
         obs = pd.read_csv(str(obs), sep='\t', header=0, index_col=0,
-                          squeeze=True)
+                          ).squeeze('columns')
         pdt.assert_series_equal(obs, exp)
 
     def test_pd_series_to_Predictions_format_allow_nans(self):
@@ -161,7 +161,7 @@ class TestSemanticTypes(SampleClassifierTestPluginBase):
                         name='prediction', index=['a', 'b', 'c', 'd'])
         obs = transformer(exp)
         obs = pd.read_csv(str(obs), sep='\t', header=0, index_col=0,
-                          squeeze=True)
+                          ).squeeze('columns')
         pdt.assert_series_equal(obs, exp)
 
     def test_Predictions_format_to_pd_series(self):
@@ -421,7 +421,28 @@ class TestTransformers(SampleEstimatorTestBase):
         def read_pipeline(pipeline_filepath):
             with tarfile.open(pipeline_filepath) as tar:
                 dirname = tempfile.mkdtemp()
-                tar.extractall(dirname)
+
+                def is_within_directory(directory, target):
+
+                    abs_directory = os.path.abspath(directory)
+                    abs_target = os.path.abspath(target)
+
+                    prefix = os.path.commonprefix([abs_directory, abs_target])
+
+                    return prefix == abs_directory
+
+                def safe_extract(tar, path=".", members=None, *,
+                                 numeric_owner=False):
+
+                    for member in tar.getmembers():
+                        member_path = os.path.join(path, member.name)
+                        if not is_within_directory(path, member_path):
+                            raise Exception("Attempted Path Traversal in Tar"
+                                            "File")
+
+                    tar.extractall(path, members, numeric_owner=numeric_owner)
+
+                safe_extract(tar, dirname)
                 pipeline = joblib.load(os.path.join(dirname,
                                        'sklearn_pipeline.pkl'))
                 for fn in tar.getnames():
